﻿using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.Core;

namespace CacheGenerator
{
    class LayerProvider
    {
        // You can insert your layer to "layersToCache" in this function, they will be used for cache.
        public static Collection<Layer> GetLayersToCache()
        {
            Collection<Layer> layersToCache = new Collection<Layer>();

            ShapeFileFeatureLayer layer = new ShapeFileFeatureLayer(@"D:\TestData\Countries02.shp", ShapeFileReadWriteMode.ReadOnly);
            layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layer.Open();

            Proj4Projection prj4 = new Proj4Projection();
            prj4.InternalProjectionParametersString = Proj4Projection.GetLatLongParametersString();
            prj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
            prj4.Open();
            layer.FeatureSource.Projection = prj4;

            layersToCache.Add(layer);

            return layersToCache;
        }

        
        public static Collection<double> GetScalesToCache(GeographyUnit geoUnit)
        {
            ZoomLevelSet zoomLevelSet = new ZoomLevelSet();
            if (geoUnit == GeographyUnit.Meter)
                //zoomLevelSet = new SphericalMercatorZoomLevelSet(); 
                zoomLevelSet = new MyZoomlevelSet();
            else
                zoomLevelSet = new ZoomLevelSet(); 

            Collection<double> scalesToCache = new Collection<double>();
            scalesToCache.Add(zoomLevelSet.ZoomLevel01.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel02.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel03.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel04.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel05.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel06.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel07.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel08.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel09.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel10.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel11.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel12.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel13.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel14.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel15.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel16.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel17.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel18.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel19.Scale);
            scalesToCache.Add(zoomLevelSet.ZoomLevel20.Scale);

            return scalesToCache;
        }

        class MyZoomlevelSet : ZoomLevelSet
        {

            public MyZoomlevelSet()
            {
                ZoomLevel20.Scale = 564.25;
                ZoomLevel19.Scale = 1128.5;
                ZoomLevel18.Scale = 2257;
                ZoomLevel17.Scale = 4514;
                ZoomLevel16.Scale = 9028;
                ZoomLevel15.Scale = 18055.99;
                ZoomLevel14.Scale = 36111.98;
                ZoomLevel13.Scale = 72223.96;
                ZoomLevel12.Scale = 144447.93;
                ZoomLevel11.Scale = 288895.85;
                ZoomLevel10.Scale = 577791.71;
                ZoomLevel09.Scale = 1155583.42;
                ZoomLevel08.Scale = 2311166.84;
                ZoomLevel07.Scale = 4622333.68;
                //ZoomLevel06.Scale = 9244677.36;
                //ZoomLevel05.Scale = 18489334.72;
                //ZoomLevel04.Scale = 36978669.43;
                //ZoomLevel03.Scale = 73957338.86;
                ZoomLevel06.Scale = 9886730.47925373;
                ZoomLevel05.Scale = 19773460.9585075;
                ZoomLevel04.Scale = 39546921.9170149;
                ZoomLevel03.Scale = 79093843.8340299;

                ZoomLevel02.Scale = 147914677.73;
                ZoomLevel01.Scale = 295829355.45;
            }
        }
    }
}
